// This file is automatically generated and updated by Zygoat and should not
// be edited manually. To extend or overwrite these settings, edit
// next.config.js

const withSvgr = require('next-svgr');
const withImages = require('next-images');

const prod = process.env.NODE_ENV === 'production';

const config = {
  webpack: webpackConfig => {
    webpackConfig.resolve.alias['@@'] = __dirname;
    webpackConfig.resolve.alias['@wui'] = '@bequestinc/wui';
    return webpackConfig;
  },
  env: {
    PROD: prod,
  },
};

const withImagesConfig = {
  exclude: /\.svg$/,
};

const plugins = [withSvgr, [withImages, withImagesConfig]];

module.exports = { plugins, config };
